Changelog
=========

0.1.1
-----

* Memory leak detection via ``memleak_threshold``
* Tox and Travis-CI tests!

0.1.0
-----

* A super sweet name. Much better than AwesomeResultTask.
* This changelog
* Hope?
